@@ -56,12 +56,12 @@ KeyboardBrightnessControl::KeyboardBrightnessControl(QObject* parent)
     KActionCollection* actionCollection = new KActionCollection( this );
     KGlobalAccel *accel = KGlobalAccel::self();
 
-    QAction *globalAction = actionCollection->addAction("Increase Keyboard Brightness");
+    QAction *globalAction = actionCollection->addAction(QLatin1String("Increase Keyboard Brightness"));
     globalAction->setText(i18nc("@action:inmenu Global shortcut", "Increase Keyboard Brightness"));
     accel->setGlobalShortcut(globalAction, Qt::Key_KeyboardBrightnessUp);
     connect(globalAction, SIGNAL(triggered(bool)), SLOT(increaseKeyboardBrightness()));
 
-    globalAction = actionCollection->addAction("Decrease Keyboard Brightness");
+    globalAction = actionCollection->addAction(QLatin1String("Decrease Keyboard Brightness"));
     globalAction->setText(i18nc("@action:inmenu Global shortcut", "Decrease Keyboard Brightness"));
     accel->setGlobalShortcut(globalAction, Qt::Key_KeyboardBrightnessDown);
     connect(globalAction, SIGNAL(triggered(bool)), SLOT(decreaseKeyboardBrightness()));
@@ -99,7 +99,7 @@ void KeyboardBrightnessControl::onProfileLoad()
     // if the current profile is more conservative than the previous one and the
     // current brightness is lower than the new profile
     if (((m_currentProfile == QLatin1String("Battery") && m_lastProfile == QLatin1String("AC")) ||
-         (m_currentProfile == QLatin1String("LowBattery") && (m_lastProfile == "AC" || m_lastProfile == "Battery"))) &&
+         (m_currentProfile == QLatin1String("LowBattery") && (m_lastProfile == QLatin1String("AC") || m_lastProfile == QLatin1String("Battery")))) &&
         absoluteKeyboardBrightnessValue > keyboardBrightness()) {
 
         // We don't want to change anything here
@@ -110,8 +110,8 @@ void KeyboardBrightnessControl::onProfileLoad()
         };
 
         // plugging in/out the AC is always explicit
-        if ((m_currentProfile == "AC" && m_lastProfile != "AC") ||
-            (m_currentProfile != "AC" && m_lastProfile == "AC")) {
+        if ((m_currentProfile == QLatin1String("AC") && m_lastProfile != QLatin1String("AC")) ||
+            (m_currentProfile != QLatin1String("AC") && m_lastProfile == QLatin1String("AC"))) {
             args["Explicit"] = true;
             args["Silent"] = true; // but we still don't want to show the OSD then
         }
